Control

Struct Control 

pub struct Control { /* private fields */ }
Available on Windows only.
Allows closing and awaiting exit of a Reactor.

Implementations

Source

impl Control

pub fn close(&self)

Stops accepting new Reactor::submit calls on every clone of the corresponding Reactor.

pub fn join(self) -> Join

Returns a future which awaits the reactor thread’s exit.

The reactor thread will not exit until all work completes and no more can be submitted. This means that if close is not called first, this function implicitly waits for every Reactor clone to be dropped in addition to all work completing. Join::close on the returned join handle can be used to make a late-binding decision to close the reactor.