pub enum AclError {
Length(usize),
Size(u16, usize),
AceCount(u16, usize),
Ace(usize, AceError),
}Expand description
Error returned when parsing an ACL.
Variants
Length(usize)
The packet is shorter than an ACL header or is not DWORD-aligned.
Size(u16, usize)
The declared packet size differs from the supplied byte length.
AceCount(u16, usize)
Fewer ACE packets could be read than the header declares.
Ace(usize, AceError)
An ACE at the supplied index is malformed.