pub struct AccessMask(/* private fields */);Expand description
Generic ACCESS_MASK flags.
These apply to any securable object type (registry keys, services, files, …), as opposed to
bits whose meaning is specific to one object type (e.g. KEY_QUERY_VALUE, SERVICE_START).
Implementations
Sourceimpl AccessMask
impl AccessMask
Sourcepub const SPECIFIC_RIGHTS_ALL: Self
pub const SPECIFIC_RIGHTS_ALL: Self
All object-specific rights in the low 16 bits.
Sourcepub const READ_CONTROL: Self
pub const READ_CONTROL: Self
Grants the right to read the object’s security descriptor.
Sourcepub const WRITE_OWNER: Self
pub const WRITE_OWNER: Self
Grants the right to change the owner or primary group.
Sourcepub const SYNCHRONIZE: Self
pub const SYNCHRONIZE: Self
Grants the synchronization right.
Sourcepub const STANDARD_RIGHTS_REQUIRED: Self
pub const STANDARD_RIGHTS_REQUIRED: Self
Combines the standard rights required by an object type.
Sourcepub const STANDARD_RIGHTS_ALL: Self
pub const STANDARD_RIGHTS_ALL: Self
Combines all standard rights.
Sourcepub const ACCESS_SYSTEM_SECURITY: Self
pub const ACCESS_SYSTEM_SECURITY: Self
Requests access to the system ACL; enabling SeSecurityPrivilege may be required.
Sourcepub const MAXIMUM_ALLOWED: Self
pub const MAXIMUM_ALLOWED: Self
Asks the system to grant the maximum permitted access.
Sourcepub const GENERIC_ALL: Self
pub const GENERIC_ALL: Self
Generic all-access mapping bit.
Sourcepub const GENERIC_EXECUTE: Self
pub const GENERIC_EXECUTE: Self
Generic execute-access mapping bit.
Sourcepub const GENERIC_WRITE: Self
pub const GENERIC_WRITE: Self
Generic write-access mapping bit.
Sourcepub const GENERIC_READ: Self
pub const GENERIC_READ: Self
Generic read-access mapping bit.
Sourceimpl AccessMask
impl AccessMask
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AccessMask
impl AccessMask
Sourcepub const fn iter(&self) -> Iter<AccessMask> ⓘ
pub const fn iter(&self) -> Iter<AccessMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AccessMask> ⓘ
pub const fn iter_names(&self) -> IterNames<AccessMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl AccessMask
impl AccessMask
Sourcepub const fn specific_rights(self) -> u16
pub const fn specific_rights(self) -> u16
Returns the object-specific low 16 bits.
Sourcepub const fn from_specific_rights(rights: u16) -> Self
pub const fn from_specific_rights(rights: u16) -> Self
Creates a mask from object-specific low 16 bits.
Sourcepub const fn standard_rights(self) -> Self
pub const fn standard_rights(self) -> Self
Returns the standard and system-access rights.
Sourcepub const fn generic_rights(self) -> Self
pub const fn generic_rights(self) -> Self
Returns the generic mapping rights.